yakumo.neutron.v2.subnet.Resource

Package yakumo :: Package neutron :: Package v2 :: Module subnet :: Class Resource |
[hide private]
[frames] | no frames]

# Class Resource

source code

       object --+
                |
    base.Resource --+
                    |
                   Resource

Resource class for subnets in Networking V2 API

Instance Methods | [hide private]
None |
update(self, name=`'``__UNDEF__``'`, allocation_pools=`'``__UNDEF__``'`, gateway_ip=`'``__UNDEF__``'`, is_dhcp_enabled=`'``__UNDEF__``'`, dns_nameservers=`'``__UNDEF__``'`, host_routes=`'``__UNDEF__``'`) Update properties of a subnet | source code
Inherited from `base.Resource`: `__eq__`, `__getattr__`, `__init__`, `__ne__`, `__repr__`, `__str__`, `delete`, `get_attrs`, `get_id`, `reload`, `wait_for_finished` Inherited from `base.Resource` (private): `_clear_attrs`, `_set_attrs` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Class Variables | [hide private]
Inherited from `base.Resource` (private): `_attrs`, `_id`, `_loaded`, `_stable_state`, `_state_attr`, `_sub_manager_list`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### update(self, name=`'``__UNDEF__``'`, allocation_pools=`'``__UNDEF__``'`, gateway_ip=`'``__UNDEF__``'`, is_dhcp_enabled=`'``__UNDEF__``'`, dns_nameservers=`'``__UNDEF__``'`, host_routes=`'``__UNDEF__``'`) | source code
Update properties of a subnet Parameters: `name` (str) - Subnet name `allocation_pools` (str) - Allocation pools `gateway_ip` (str) - Gateway IP address `is_dhcp_enabled` (bool) - Whether DHCP is enabled `dns_nameservers` (str) - DNS nameservers `host_routes` (str) - Host routes Returns: None Overrides: base.Resource.update